@@ -33,15 +33,16 @@ BEGIN {
         *img_info = sub {
             my $file = shift;
             my @stuff = Image::Size::imgsize($file);
-            return { "width"  => $stuff[0],
-                     "height" => $stuff[1],
-                     "error"  =>
-                        # imgsize returns either a three letter file type
-                        # or an error message as third value
-                        (defined($stuff[2]) && length($stuff[2]) > 3
-                            ? $stuff[2]
-                            : undef),
-                   };
+            return {
+                "width"  => $stuff[0],
+                "height" => $stuff[1],
+                "error"  =>
+                    # imgsize returns either a three letter file type
+                    # or an error message as third value
+                    (defined($stuff[2]) && length($stuff[2]) > 3
+                        ? $stuff[2]
+                        : undef),
+            };
         }
     }
     else {
@@ -55,7 +56,7 @@ BEGIN {
 # new($context, $name, \%config)
 #
 # Create a new Image object.  Takes the pathname of the file as
-# the argument following the context and an optional 
+# the argument following the context and an optional
 # hash reference of configuration parameters.
 #------------------------------------------------------------------------
 
@@ -71,7 +72,7 @@ sub new {
         unless defined $name and length $name;
 
     # name can be specified as an absolute path or relative
-    # to a root directory 
+    # to a root directory
 
     if ($root = $config->{ root }) {
         $file = File::Spec->catfile($root, $name);
@@ -88,7 +89,7 @@ sub new {
     $config->{ alt } = '' unless defined $config->{ alt };
 
     # do we want to check to see if file exists?
-    bless { 
+    bless {
         %$config,
         name => $name,
         file => $file,
@@ -293,7 +294,7 @@ Typical output:
 
     <img src="foo.gif" width="60" height="20" alt="" />
 
-You can provide any additional attributes that should be added to the 
+You can provide any additional attributes that should be added to the
 XHTML tag.
 
     [% USE image 'foo.gif' %]
@@ -305,7 +306,7 @@ Typical output:
 
 Note that the C<alt> attribute is mandatory in a strict XHTML C<img>
 element (even if it's empty) so it is always added even if you don't
-explicitly provide a value for it.  You can do so as an argument to 
+explicitly provide a value for it.  You can do so as an argument to
 the C<tag> method, as shown in the previous example, or as an argument
 
     [% USE image('foo.gif', alt='Logo') %]
@@ -416,7 +417,7 @@ Andy Wardley E<lt>abw@wardley.orgE<gt> L<http://wardley.org/>
 
 =head1 COPYRIGHT
 
-Copyright (C) 1996-2007 Andy Wardley.  All Rights Reserved.
+Copyright (C) 1996-2022 Andy Wardley.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
